@@ -19,7 +19,9 @@ def rjindael_encrypt_gen(key, s, block_size=pprp.config.DEFAULT_BLOCK_SIZE):
             block += (chr(padding_size) * padding_size).encode('ASCII')
             padded = True
 
-        _logger.debug("Encrypting and yielding encrypted block: (%d)", i)
+        _logger.debug("Encrypting and yielding encrypted block: (%d) (%d)", 
+                      i, len_)
+
         yield r.encrypt(block)
         i += 1
 
@@ -32,5 +34,6 @@ def rjindael_decrypt_gen(key, s, block_size=pprp.config.DEFAULT_BLOCK_SIZE):
     i = 0
     for block in s:
         _logger.debug("Decrypting and yielding decrypted block: (%d)", i)
+
         yield r.decrypt(block)
         i += 1
